require 'test_helper'

module Workarea
  module Storefront
    class CartItemRegistryIntegrationTest < Workarea::IntegrationTest
      setup :registry, :product

      def registry
        @registry ||= create_registry
      end

      def product
        @product ||= create_product(
          name: 'Integration Product',
          variants: [
            { sku: 'SKU1', regular: 5.to_m },
            { sku: 'SKU2', regular: 6.to_m }
          ]
        )
      end

      def order
        Order.first
      end

      def test_create_item_from_registry
        registry_item = create_registry_item({
          registry: registry,
          product_id: product.id,
          sku: product.variants.first.sku
        })

        post storefront.cart_items_path,
             params: {
               product_id: registry_item.product_id,
               sku: registry_item.sku,
               quantity: 1,
               registry_id: registry.id
             }

        assert(response.ok?)

        order.reload
        assert_equal(@product.id, order.items.first.product_id)
        assert_equal(@product.skus.first, order.items.first.sku)
        assert_equal(1, order.items.first.quantity)
        assert_equal(5.to_m, order.items.first.total_price)
        assert_equal(@registry.id.to_s, order.items.first.registry_id)
      end

      def test_cannot_create_more_items_than_requested
        registry_item = create_registry_item({
          registry: registry,
          product_id: product.id,
          sku: product.variants.first.sku,
          received: 1
        })

        post storefront.cart_items_path,
           params: {
             product_id: registry_item.product_id,
             sku: registry_item.sku,
             quantity: 2,
             registry_id: @registry.id
           }

        assert(response.ok?)

        order.reload
        assert_equal(@product.id, order.items.first.product_id)
        assert_equal(@product.skus.first, order.items.first.sku)
        assert_equal(1, order.items.first.quantity)
        assert_equal(5.to_m, order.items.first.total_price)
        assert_equal(@registry.id.to_s, order.items.first.registry_id)
      end

      def test_cannot_add_more_quantity_than_requested
        registry_item = create_registry_item({
          registry: registry,
          product_id: product.id,
          sku: product.variants.first.sku,
          received: 1
        })

        post storefront.cart_items_path,
           params: {
             product_id: registry_item.product_id,
             sku: registry_item.sku,
             quantity: 2,
             registry_id: @registry.id
           }

        assert(response.ok?)

        order.reload
        assert_equal(product.id, order.items.first.product_id)
        assert_equal(product.skus.first, order.items.first.sku)
        assert_equal(1, order.items.first.quantity)
        assert_equal(5.to_m, order.items.first.total_price)
        assert_equal(registry.id.to_s, order.items.first.registry_id)
      end
    end
  end
end
