require 'test_helper'

module Workarea
  module Storefront
    class CheckoutRegistryIntegrationTest < Workarea::IntegrationTest
      include Storefront::IntegrationTest
      setup :setup_registry_checkout

      def setup_registry_checkout
        create_checkout_with_registry_item
      end

      def order
        Order.first
      end

      def registry
        Registry.first
      end

      def test_checkout_ship_to_registrant
        patch storefront.checkout_addresses_path,
          params: {
            ship_to_registrant: true,
            email: 'bcrouse@workarea.com',
            billing_address: {
              first_name:   'Ben',
              last_name:    'Crouse',
              street:       '12 N. 3rd St.',
              city:         'Philadelphia',
              region:       'PA',
              postal_code:  '19106',
              country:      'US',
              phone_number: '2159251800'
            },
            registry_shipping_address: {
              first_name:   'Ben',
              last_name:    'Crouse',
              street:       '22 S. 3rd St.',
              city:         'Philadelphia',
              region:       'PA',
              postal_code:  '19106',
              country:      'US',
              phone_number: '2159251800'
            }
          }

        patch storefront.checkout_shipping_path

        patch storefront.checkout_place_order_path,
          params: {
            payment: 'new_card',
            credit_card: {
              number: '1',
              month:  1,
              year:   next_year,
              cvv:    '999'
            }
          }

        assert_equal(true, order.ship_to_registrant)
        assert(order.placed?)
      end

      def test_checkout_ship_to_another_address
        patch storefront.checkout_addresses_path,
          params: {
            ship_to_registrant: false,
            email: 'bcrouse@workarea.com',
            billing_address: {
              first_name:   'Ben',
              last_name:    'Crouse',
              street:       '12 N. 3rd St.',
              city:         'Philadelphia',
              region:       'PA',
              postal_code:  '19106',
              country:      'US',
              phone_number: '2159251800'
            },
            shipping_address: {
              first_name:   'Ben',
              last_name:    'Crouse',
              street:       '22 S. 3rd St.',
              city:         'Philadelphia',
              region:       'PA',
              postal_code:  '19106',
              country:      'US',
              phone_number: '2159251800'
            }
          }

        patch storefront.checkout_shipping_path

        patch storefront.checkout_place_order_path,
          params: {
            payment: 'new_card',
            credit_card: {
              number: '1',
              month:  1,
              year:   next_year,
              cvv:    '999'
            }
          }

        assert_equal(false, order.ship_to_registrant)
        assert(order.placed?)
      end

      def test_mark_registry_items_as_purchased
        patch storefront.checkout_addresses_path,
          params: {
            ship_to_registrant: true,
            email: 'bcrouse@workarea.com',
            billing_address: {
              first_name:   'Ben',
              last_name:    'Crouse',
              street:       '12 N. 3rd St.',
              city:         'Philadelphia',
              region:       'PA',
              postal_code:  '19106',
              country:      'US',
              phone_number: '2159251800'
            },
            registry_shipping_address: {
              first_name:   'Ben',
              last_name:    'Crouse',
              street:       '22 S. 3rd St.',
              city:         'Philadelphia',
              region:       'PA',
              postal_code:  '19106',
              country:      'US',
              phone_number: '2159251800'
            }
          }

        patch storefront.checkout_shipping_path

        patch storefront.checkout_place_order_path,
          params: {
            payment: 'new_card',
            credit_card: {
              number: '1',
              month:  1,
              year:   next_year,
              cvv:    '999'
            }
          }

        assert(2, registry.items.count)
        assert(1, registry.items.first.received)
        assert('bcrouse@workarea.com', registry.items.last.purchased_by)
        assert(1, registry.purchased_items)
      end
    end
  end
end
