require 'test_helper'

module Workarea
  module Storefront
    class RegistryPrivacyIntegrationTest < Workarea::IntegrationTest
      setup :user, :registry

      def user
        @user ||= create_user(password: 'w0rkArea!')
      end

      def registry
        @registry ||= create_registry({ user_id: @user.id })
      end

      def test_navigate_to_public_registry
        get storefront.registry_path(registry)

        assert(response.ok?)
      end

      def test_navigate_to_shared_registry
        registry.update(privacy: 'shared')
        get storefront.registry_path(registry)

        assert(response.ok?)
      end

      def test_navigate_to_private_registry
        registry.update(privacy: 'private')
        get storefront.registry_path(registry)

        assert_redirected_to(storefront.registries_path)
      end

      def test_navigating_to_private_registry_as_owner
        registry.update(privacy: 'private')

        post storefront.login_path,
             params: { email: user.email, password: 'w0rkArea!' }

        get storefront.registry_path(registry)

        assert(response.ok?)
      end
    end
  end
end
